@@ -5,8 +5,9 @@
     Copyright (c) 2004 Klarälvdalens Datakonsult AB
 
     Libkleopatra is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License,
-    version 2, as published by the Free Software Foundation.
+    modify it under the terms of the GNU General Public License as
+    published by the Free Software Foundation; either version 2 of the
+    License, or (at your option) any later version.
 
     Libkleopatra is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -32,7 +33,7 @@
 #include "cryptoconfigdialog.h"
 #include "cryptoconfigmodule.h"
 #include <KLocalizedString>
-#include <kacceleratormanager.h>
+#include <KAcceleratorManager>
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <KGuiItem>
@@ -41,7 +42,7 @@
 Kleo::CryptoConfigDialog::CryptoConfigDialog(QGpgME::CryptoConfig *config, QWidget *parent)
     : QDialog(parent)
 {
-    setWindowTitle(i18n("Configure GnuPG Backend"));
+    setWindowTitle(i18nc("@title:window", "Configure GnuPG Backend"));
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     mButtonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::RestoreDefaults | QDialogButtonBox::Apply, this);
     QPushButton *okButton = mButtonBox->button(QDialogButtonBox::Ok);
